from django import template
from django.contrib.contenttypes.models import ContentType

register = template.Library()


@register.simple_tag
def get_url(model_name, action):

    model = ContentType.objects.get(model=model_name.lower())
    app_name = model.model_class()._meta.app_label
    urls_dict = f'{ model_name.lower() }_urls'
    urls = getattr(__import__(f'{ app_name }.configs', fromlist=[urls_dict]), urls_dict)
    url = urls.get(action, None)

    return url if url is not None else ''

@register.simple_tag
def get_order(order):

    if '-' in order:
        new_order = order.split('-')[1]
    else:
        new_order = f'-{ order }'

    return new_order


@register.simple_tag
def get_breadcrumbs(url):

    return url.split('/')



from django.core.management.base import BaseCommand
from django.conf import settings

from dashboard.generators import AbstractGenerator


class Command(BaseCommand):
    """
    """

    help = 'Generate'

    def add_arguments(self, parser):

        parser.add_argument('app_name', type=str, help='App name to generate.')

        parser.add_argument('--urls', action='store_true', help='Only generate urls')
        parser.add_argument('--forms', action='store_true', help='Only generate forms')
        parser.add_argument('--filters', action='store_true', help='Only generate filters')
        parser.add_argument('--views', action='store_true', help='Only generate views')

    def handle(self, *args, **kwargs):

        app_name = kwargs['app_name']
        app_module = None

        urls = kwargs['urls']
        forms = kwargs['forms']
        filters = kwargs['filters']
        views = kwargs['views']

        all = not urls and not forms and not filters and not views
        
        for app in settings.CUSTOM_INSTALLED_APPS:
            if app == app_name:
                app_module = True
                break
        
        if not app_module:
            raise Exception(f'App name "{ app_name }" not installed.')
        
        generator = AbstractGenerator(app)

        # Urls
        if all or urls:
            generator.generate_urls()

        # Forms
        if all or forms:
            generator.generate_forms()

        # Filters
        if all or filters:
            generator.generate_filters()

        # Views
        if all or views:
            generator.generate_views()




import setuptools

setuptools.setup(
    name='django-dashboards-app',
    version='1.0.0',
    author='Alberto Sanmartin Martinez',
    author_email='info@albertosanmartinmartinez.es',
    url='https://gitlab.com/albertosanmartinmartinez/django-dashboards',
    license='LICENSE.txt',
    description='Django Dashboard',
    long_description='Django Admin for Developers and Django Dahsboard for Clients',
    install_requires=[
        "django-filter>=22.1",
        "django-widget-tweaks>=1.4.8"
    ],
    package_dir={"": "."},
    packages=setuptools.find_packages(where="."),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3"
)